==> jc-1.4.0.tar.gz: java/util/Stack.h <==
// public class java.util.Stack

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class 72209734bd9cc6c1 java_util_Stack
// @dep_class c53e1575b095109b java_util_Vector

// header file dependencies
// @dep_header java_util_Vector

#include "java/util/Vector.h"

#ifndef _JC_java_util_Stack_H_
#define _JC_java_util_Stack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_util_Stack$sub_refs	_jc_java_util_Stack$sub_refs;
typedef struct _jc_java_util_Stack$sub_nonrefs	_jc_java_util_Stack$sub_nonrefs;
typedef struct _jc_java_util_Stack$refs	_jc_java_util_Stack$refs;
typedef struct _jc_java_util_Stack$nonrefs	_jc_java_util_Stack$nonrefs;
typedef struct _jc_java_util_Stack$object	_jc_java_util_Stack$object;

typedef struct _jc_java_util_Stack$fields_struct	_jc_java_util_Stack$fields_struct;
typedef const struct _jc_java_util_Stack$vmethods	_jc_java_util_Stack$vmethods;
typedef const struct _jc_java_util_Stack$vtable	_jc_java_util_Stack$vtable;
typedef const struct _jc_java_util_Stack$vtype	_jc_java_util_Stack$vtype;

// Class fields structure
struct _jc_java_util_Stack$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Stack$fields_struct _jc_java_util_Stack$class_fields;

// Constructors
extern void _jc_java_util_Stack$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_Stack$object *);

// Virtual methods
extern jboolean _jc_java_util_Stack$method$empty$a66e7e55a0392358(_jc_env *, struct _jc_java_util_Stack$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Stack$method$peek$6b96fe40eaab07ac(_jc_env *, struct _jc_java_util_Stack$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Stack$method$pop$77614809bf65e8ac(_jc_env *, struct _jc_java_util_Stack$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Stack$method$push$93039e6bf07d4123(_jc_env *, struct _jc_java_util_Stack$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_util_Stack$method$search$48e4bb20670963fd(_jc_env *, struct _jc_java_util_Stack$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Stack$method_info$empty$a66e7e55a0392358;
extern _jc_method _jc_java_util_Stack$method_info$peek$6b96fe40eaab07ac;
extern _jc_method _jc_java_util_Stack$method_info$pop$77614809bf65e8ac;
extern _jc_method _jc_java_util_Stack$method_info$push$93039e6bf07d4123;
extern _jc_method _jc_java_util_Stack$method_info$search$48e4bb20670963fd;

// Virtual methods structure
struct _jc_java_util_Stack$vmethods {
	jboolean	(*empty$a66e7e55a0392358)(_jc_env *, struct _jc_java_util_Stack$object *);
	struct _jc_java_lang_Object$object	*(*peek$6b96fe40eaab07ac)(_jc_env *, struct _jc_java_util_Stack$object *);
	struct _jc_java_lang_Object$object	*(*pop$77614809bf65e8ac)(_jc_env *, struct _jc_java_util_Stack$object *);
	struct _jc_java_lang_Object$object	*(*push$93039e6bf07d4123)(_jc_env *, struct _jc_java_util_Stack$object *, struct _jc_java_lang_Object$object *);
	jint	(*search$48e4bb20670963fd)(_jc_env *, struct _jc_java_util_Stack$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_util_Stack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_Vector$vmethods	java_util_Vector;
	_jc_java_util_Stack$vmethods	java_util_Stack;
};

// Vtype
struct _jc_java_util_Stack$vtype {
	_jc_type			type;
	_jc_java_util_Stack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Stack$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Stack$refs {
    _jc_java_util_Stack$sub_refs	java_util_Stack;
    _jc_java_util_Vector$sub_refs	java_util_Vector;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Stack$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Stack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_Vector$sub_nonrefs	java_util_Vector;
    _jc_java_util_Stack$sub_nonrefs	java_util_Stack;
};

// Object instance structure
struct _jc_java_util_Stack$object {
	_jc_java_util_Stack$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Stack$vtype	*vtype;
	_jc_java_util_Stack$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Stack$vtype _jc_java_util_Stack$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Stack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Stack$class_object;

#endif	/* _JC_java_util_Stack_H_ */

==> jc-1.4.6.tar.gz: java/util/Stack.h <==
// public class java.util.Stack

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class 72209734bd9cc6c1 java_util_Stack
// @dep_class c53e1575b095109b java_util_Vector

// header file dependencies
// @dep_header java_util_Vector

#include "java/util/Vector.h"

#ifndef _JC_java_util_Stack_H_
#define _JC_java_util_Stack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_util_Stack$sub_refs	_jc_java_util_Stack$sub_refs;
typedef struct _jc_java_util_Stack$sub_nonrefs	_jc_java_util_Stack$sub_nonrefs;
typedef struct _jc_java_util_Stack$refs	_jc_java_util_Stack$refs;
typedef struct _jc_java_util_Stack$nonrefs	_jc_java_util_Stack$nonrefs;
typedef struct _jc_java_util_Stack$object	_jc_java_util_Stack$object;

typedef struct _jc_java_util_Stack$fields_struct	_jc_java_util_Stack$fields_struct;
typedef const struct _jc_java_util_Stack$vmethods	_jc_java_util_Stack$vmethods;
typedef const struct _jc_java_util_Stack$vtable	_jc_java_util_Stack$vtable;
typedef const struct _jc_java_util_Stack$vtype	_jc_java_util_Stack$vtype;

// Class fields structure
struct _jc_java_util_Stack$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Stack$fields_struct _jc_java_util_Stack$class_fields;

// Constructors
extern void _jc_java_util_Stack$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_Stack$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_Stack$method$empty$a66e7e55a0392358(_jc_env *, struct _jc_java_util_Stack$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Stack$method$peek$6b96fe40eaab07ac(_jc_env *, struct _jc_java_util_Stack$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Stack$method$pop$77614809bf65e8ac(_jc_env *, struct _jc_java_util_Stack$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Stack$method$push$93039e6bf07d4123(_jc_env *, struct _jc_java_util_Stack$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Stack$method$search$48e4bb20670963fd(_jc_env *, struct _jc_java_util_Stack$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Stack$method_info$empty$a66e7e55a0392358;
extern _jc_method _jc_java_util_Stack$method_info$peek$6b96fe40eaab07ac;
extern _jc_method _jc_java_util_Stack$method_info$pop$77614809bf65e8ac;
extern _jc_method _jc_java_util_Stack$method_info$push$93039e6bf07d4123;
extern _jc_method _jc_java_util_Stack$method_info$search$48e4bb20670963fd;

// Virtual methods structure
struct _jc_java_util_Stack$vmethods {
	jboolean	(*empty$a66e7e55a0392358)(_jc_env *, struct _jc_java_util_Stack$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*peek$6b96fe40eaab07ac)(_jc_env *, struct _jc_java_util_Stack$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*pop$77614809bf65e8ac)(_jc_env *, struct _jc_java_util_Stack$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*push$93039e6bf07d4123)(_jc_env *, struct _jc_java_util_Stack$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*search$48e4bb20670963fd)(_jc_env *, struct _jc_java_util_Stack$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Stack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_Vector$vmethods	java_util_Vector;
	_jc_java_util_Stack$vmethods	java_util_Stack;
};

// Vtype
struct _jc_java_util_Stack$vtype {
	_jc_type			type;
	_jc_java_util_Stack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Stack$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Stack$refs {
    _jc_java_util_Stack$sub_refs	java_util_Stack;
    _jc_java_util_Vector$sub_refs	java_util_Vector;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Stack$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Stack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_Vector$sub_nonrefs	java_util_Vector;
    _jc_java_util_Stack$sub_nonrefs	java_util_Stack;
};

// Object instance structure
struct _jc_java_util_Stack$object {
	_jc_java_util_Stack$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Stack$vtype	*vtype;
	_jc_java_util_Stack$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Stack$vtype _jc_java_util_Stack$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Stack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Stack$class_object;

#endif	/* _JC_java_util_Stack_H_ */
